==> vdr-addon-tvmovie2vdr_0.1.0.orig.tar.gz: vdr-addon-tvmovie2vdr-0.1.0.orig/inc/tvmoviefetch.pl <==

use Compress::Zlib;

################################################################################
# Get xml-files from tvmovie online
################################################################################
sub GetFiles {
	for ($days=0;$days < $days2download ;$days++) {
		doexit() if $please_exit;

		$now_string = DateCalc("today","+ $days days",\$err,0);
		$now_string = UnixDate($now_string, "%Y%m%d");
		foreach $rfcid (keys %chan) {
			doexit() if $please_exit;

			# Kanal fr tvmovie konfiguriert ?
			next if $chan{$rfcid}[1] != "1";

			$filenamexml = "$now_string"."_$chan{$rfcid}[2].xml";
			$filenamexmltvm = "$filenamexml.tvm";
			$filenamexmlgz = "$filenamexml.gz";

			if (! -e "$downloadprefix$filenamexml") {
			print "tvmovie: downloading files $baseurl$filenamexmltvm\n";
			my $dummy=GetContent("$baseurl$filenamexmltvm","$downloadprefix$filenamexmltvm");
			unscramble ("$downloadprefix$filenamexmltvm","$downloadprefix$filenamexmlgz");
			system("gunzip", "-f", "$downloadprefix$filenamexmlgz") == 0
				or warn "gunzip failed";
			}
		}
	}
}

################################################################################
# Get update xml-files from tvmovie online
################################################################################
sub GetUpdateFiles {
	$now_string = UnixDate("today", "%Y%m%d");
	foreach $rfcid (keys %chan) {
		doexit() if $please_exit;

		# Kanal fr tvmovie konfiguriert ?
		next if $chan{$rfcid}[1] != "1";

		$filenamexml = "$now_string"."_$chan{$rfcid}[2].xml";
		$filenamexmltvm = "$filenamexml.tvm";
		$filenamexmlgz = "$filenamexml.gz";

		# Updatefiles werden IMMER neu geladen
		unlink "$updateprefix$filenamexmltvm"; unlink "$updateprefix$filenamexmlgz"; unlink "$updateprefix$filenamexml";

		if (! -e "$updateprefix$filenamexml") {
			print "tvmovie: downloading update files $aendurl$filenamexmltvm\n";
			my $dummy=GetContent("$aendurl$filenamexmltvm","$updateprefix$filenamexmltvm");
			unscramble ("$updateprefix$filenamexmltvm","$updateprefix$filenamexmlgz");
			system("gunzip", "-f", "$updateprefix$filenamexmlgz") == 0
				or warn "gunzip failed";
		}
	}
}

sub unscramble
{
    #Position .gz, Positon .tvm, Lnge
    #0x0000, 0x006A, 6
    #0x0006, 0x0064, 6
    #0x000C, 0x0070, 88
    #0x0064, 0x0320, 17
    #0x0075, 0x0011, 83
    #0x00C8, 0x012C, 100
    #0x012C, 0x0000, 17
    #0x013D, 0x0331, 183
    #0x01F4, 0x0258, 200
    #0x02BC, 0x0190, 200
    #0x0384, 0x00C8, 100
    #0x03E8, 0x03E8, Rest
    my $oldfilename = shift;
    my $filename = shift;
    print "tvmovie: descrambling $oldfilename to $filename\n";
    $size = -s $oldfilename;
	if ($size <= 1000) {
        rename $oldfilename, $filename;
        return;
    }

	open(OUT, "> $filename") || die "cannot write $filename: $!";
    open(IN,  "< $oldfilename") || warn "cannot read $oldfilename: $!";
    $outstring = "";
    seek (IN,0x006a,0) && read (IN,$outstring,  6) && print OUT $outstring;
    seek (IN,0x0064,0) && read (IN,$outstring,  6) && print OUT $outstring;
    seek (IN,0x0070,0) && read (IN,$outstring, 88) && print OUT $outstring;
    seek (IN,0x0320,0) && read (IN,$outstring, 17) && print OUT $outstring;
    seek (IN,0x0011,0) && read (IN,$outstring, 83) && print OUT $outstring;
    seek (IN,0x012c,0) && read (IN,$outstring,100) && print OUT $outstring;
    seek (IN,0x0000,0) && read (IN,$outstring, 17) && print OUT $outstring;
    seek (IN,0x0331,0) && read (IN,$outstring,183) && print OUT $outstring;
    seek (IN,0x0258,0) && read (IN,$outstring,200) && print OUT $outstring;
    seek (IN,0x0190,0) && read (IN,$outstring,200) && print OUT $outstring;
    seek (IN,0x00c8,0) && read (IN,$outstring,100) && print OUT $outstring;
    seek (IN,0x03e8,0) && read (IN,$outstring,10240000) && print OUT $outstring;
    close IN;
    close OUT;
    return;
exit;
}


# Process info from XMLTV file / channels.conf 
sub ReadExternalEPG_tvmovie
{
	GetFiles();
	GetUpdateFiles() unless ($useupdate == 0);

	foreach $sender (keys(%chan)) {
		# Kanal fr tvmovie konfiguriert ?
		next if $chan{$sender}[1] != "1";
		doexit() if $please_exit;

		$id=1;
		$firstchannel=1;
		$found_orig_event=0;
		$orig_epg_id=0;
		$laststreamid = 0;
		my (@events);
		# Find XML events
		$state="";

		my ($state,$event_id,$title,$subtitle,$datum,$zeit,$dauer,$text,$kritik) = "";
		for ($days=0;$days < $days2download ;$days++) {
			doexit() if $please_exit;

			$now_string = DateCalc("today","+ $days days",\$err,0);
			$now_string = UnixDate($now_string, "%Y%m%d");
			$xmlfile = "$downloadprefix$now_string"."_"."$chan{$sender}[2].xml";
			print "tvmovie: reading $downloadprefix$now_string"."_"."$chan{$sender}[2].xml int memory\n";
			open(XMLFILE, "$xmlfile") || warn "cannot open $xmlfile: $!";
			while(<XMLFILE>) {
				chomp;

	  			#$_ =~ s/\&amp\;/\&/g;
				$_ = decode_entities($_);
				$_ =~ s/\&bull\;/\*/g;
				$_ =~ s/\&amp;bull;/\*/g;
				if ( m|\<Sendung\>|) {
					$state = "a";
					$event_id=$title=$subtitle=$datum=$zeit=$dauer= "";
					$genre=$land=$jahr=$fsk=$keywords=$text=$kritik= "";
					$summary="";
					next;
				}
				$event_id = $1				if $state eq "a" && m|<SendungID>(.*?)</SendungID>|;
				$title = $1					if $state eq "a" && m|<Titel>(.*?)</Titel>|;
				$subtitle = $1				if $state eq "a" && m|<UnterTitel>(.*?)</UnterTitel>|;
				$datum = $1					if $state eq "a" && m|<Datum>(.*?)</Datum>|;	# 2003-10-30
				$zeit = $1					if $state eq "a" && m|<Zeit>(.*?)</Zeit>|;		# 20:15:00
				$dauer = $1	* 60			if $state eq "a" && m|<Dauer>(.*?)</Dauer>|;
				$genre = $1					if $state eq "a" && m|<GenreText>(.*?)</GenreText>|;
#				$genre = $1					if $state eq "a" && m|<RZPKategorieID>(.*?)</RZPKategorieID>|;
				$land = $1					if $state eq "a" && m|<Land>(.*?)</Land>|;
				$jahr = $1					if $state eq "a" && m|<Jahr>(.*?)</Jahr>|;
				$fsk = $1					if $state eq "a" && m|<FSK>(.*?)</FSK>|;
				$state = "e"				if $state eq "a" && m|</Sendung>|;

				# Beschreibung
				$state = "t"				if $state eq "a" && m|<Text Kategorie="Inhalt">|;
				$text .= $1 . "|"			if $state eq "t" && m|<Text>(.*?)</Text>|;
				$state = "a"				if $state eq "t" && m|^\s*</Text>|;

				# Kurzkritik
				$state = "kk"				if $state eq "a"  && m|<Text Kategorie="Kurzkritik">|;
				$kritik = "Kurzkritik: $1"	if $state eq "kk" && m|<Text>(.*?)</Text>|;
				$state = "a"				if $state eq "kk" && m|^\s*</Text>|;

				if ($state eq "e") { # Ende einer Sendung erreicht
					doexit() if $please_exit;

					$start = UnixDate("$datum $zeit", "%s");
					next if (UnixDate("today", "%s") > $start+$dauer); # ist die Sendung schon vorbei ?
					$text =~ s/^(.*)\|$/$1/sig;
					
					#$kritik = $1 if kritik =~ m|^\s*(.*?)\s*$|;
					#$text = $1 if text =~ m|^\s*(.*?)\s*$|;

					$summary = "Genre: $genre|";
					$summary = "$land, $jahr, FSK: $fsk|" if $jahr != 0 && $fsk != 0;
					$summary .= "$kritik|" if $kritik ne "";
					$summary .= "$text" if $text ne "";

                    push(@events, {
						start        => $start, 
						stop         => $start + $dauer, 
						duration     => $dauer,
						title        => $title, 
						subtitle     => $subtitle, 
						summary      => $summary, 
						id           => $id,    
						event_id     => $event_id,
						state        => 1 # normale Sendung
					});
					$id++;
					$state = "";
					next;
				} # if ($state eq "e")
			} # while(<XMLFILE>) {
			close (XMLFILE);
		} # for ($days=0;$days < $days2download ;$days++) {

		# EPG-Daten sortieren
		my($last) = 0;
		my(@temp);
		for(sort({ $a->{start} <=> $b->{start} } @events)) {
			doexit() if $please_exit;
			next if($last == $_->{start});
			push(@temp, $_); 
			$last = $_->{start};
		}
		$XML{$sender} = [ @temp ];

		next unless ($useupdate == 1);
		# XML enthlt jetzt alle Daten des Senders. jetzt Updatefiles parsen und Eintrge aktualisieren
		# Okay, nicht schick. Dies gehrt in eine Prozedur, weils 2x aufgerufen wird ....
		$now_string = UnixDate("today", "%Y%m%d");
		$xmlfile = "$updateprefix$now_string"."_"."$chan{$sender}[2].xml";
		print "tvmovie: reading $updateprefix$now_string"."_"."$chan{$sender}[2].xml int memory\n";
		open(XMLFILE, "$xmlfile") || warn "cannot open $xmlfile: $!";
		while(<XMLFILE>) {
			doexit() if $please_exit;

			chomp;
			$_ =~ s/\&amp\;/\&/g;
			$_ = decode_entities($_);
			$_ =~ s/\&bull\;/\*/g;
			if ( m|\<Sendung\>|) {
				$state = "a";
				$event_id=$title=$subtitle=$datum=$zeit=$dauer= "";
				$genre=$land=$jahr=$fsk=$keywords=$text=$textt=$kritik= "";
				$summary="";
				next;
			}
			$event_id = $1				if $state eq "a" && m|<SendungID>(.*?)</SendungID>|;
			$title = $1					if $state eq "a" && m|<Titel>(.*?)</Titel>|;
			$subtitle = $1				if $state eq "a" && m|<UnterTitel>(.*?)</UnterTitel>|;
			$datum = $1					if $state eq "a" && m|<Datum>(.*?)</Datum>|;	# 2003-10-30
			$zeit = $1					if $state eq "a" && m|<Zeit>(.*?)</Zeit>|;		# 20:15:00
			$dauer = $1	* 60			if $state eq "a" && m|<Dauer>(.*?)</Dauer>|;
			$genre = $1					if $state eq "a" && m|<GenreText>(.*?)</GenreText>|;
#			$genre = $1					if $state eq "a" && m|<RZPKategorieID>(.*?)</RZPKategorieID>|;
			$land = $1					if $state eq "a" && m|<Land>(.*?)</Land>|;
			$jahr = $1					if $state eq "a" && m|<Jahr>(.*?)</Jahr>|;
			$fsk = $1					if $state eq "a" && m|<FSK>(.*?)</FSK>|;
			$state = "e"				if $state eq "a" && m|</Sendung>|;

			# Beschreibung
			$state = "t"				if $state eq "a" && m|<Text Kategorie="Inhalt">|;
			$text .= $1 . "|"			if $state eq "t" && m|<Text>(.*?)</Text>|;
			$state = "a"				if $state eq "t" && m|^\s*</Text>|;

			# Thema (bei Dokus)
			$state = "th"				if $state eq "a" && m|<Text Kategorie="Thema">|;
			$textt .= $1 . "|"			if $state eq "th" && m|<Text>(.*?)</Text>|;
			$state = "a"				if $state eq "th" && m|^\s*</Text>|;

			# Kurzkritik
			$state = "kk"				if $state eq "a"  && m|<Text Kategorie="Kurzkritik">|;
			$kritik = "Kurzkritik: $1"	if $state eq "kk" && m|<Text>(.*?)</Text>|;
			$state = "a"				if $state eq "kk" && m|^\s*</Text>|;

			if ($state eq "e") { # Ende einer Sendung erreicht
				$start = UnixDate("$datum $zeit", "%s");
				next if (UnixDate("today", "%s") > $start+$dauer); # ist die Sendung schon vorbei ?
				$text =~ s/^(.*)\|$/$1/sig;
				$textt =~ s/^(.*)\|$/$1/sig;
				
				#$kritik = $1 if kritik =~ m|^\s*(.*?)\s*$|;
				#$text = $1 if text =~ m|^\s*(.*?)\s*$|;

				$summary = "";
				$summary = "$land, $jahr, FSK: $fsk|" if $jahr != 0 && $fsk != 0;
				$summary .= "$kritik|" if $kritik ne "";
				$summary .= "Thema: $textt|" if $textt ne "";
				$summary .= "$text" if $text ne "";

				for ($i=0; $i<$#{$XML{$sender}};$i++) {
					if (@{$XML{$sender}}[$i]->{event_id} eq $event_id) {
						print "updating $title\n";
						@{$XML{$sender}}[$i]->{start}        = $start;
						@{$XML{$sender}}[$i]->{stop}         = $start + $dauer;
						@{$XML{$sender}}[$i]->{duration}     = $dauer;
						@{$XML{$sender}}[$i]->{title}        = $title; 
						@{$XML{$sender}}[$i]->{subtitle}     = $subtitle;
						@{$XML{$sender}}[$i]->{summary}      = $summary; 
						@{$XML{$sender}}[$i]->{state}        = 2; # aktualisierte Sendung

						# Updatesendung, die als Livesendung andere Sendungen ausblendet?
						for ($j=0; $j<$#{$XML{$sender}};$j++) {
							if (@{$XML{$sender}}[$j]->{state} eq 0 && 
								@{$XML{$sender}}[$j]->{start} >= $start &&
								@{$XML{$sender}}[$j]->{stop} < $start + $dauer) {
									@{$XML{$sender}}[$j]->{state}        = 0; # gelschte Sendung

							}
						}
					}
				}

				$id++;
				$state = "";
				next;
			} # if ($state eq "e")
		} # while(<XMLFILE>) {
		close (XMLFILE);
		# XML enthlt jetzt auch die nderungen
	} # foreach $sender (keys(%chan))
} # sub ProcessEpg

return 1;

==> vdr-addon-tvmovie2vdr_0.1.5.orig.tar.gz: vdr-addon-tvmovie2vdr-0.1.5.orig/inc/tvmoviefetch.pl <==

use Compress::Zlib;

################################################################################
# Get xml-files from tvmovie online
################################################################################
sub GetFiles {
	for ($days=0;$days < $days2download ;$days++) {
		doexit() if $please_exit;

		$now_string = DateCalc("heute","+ $days tage",\$err,0);
		$now_string = UnixDate($now_string, "%Y%m%d");
		foreach $rfcid (keys %chan) {
			doexit() if $please_exit;

			# Kanal fr tvmovie konfiguriert ?
			next if $chan{$rfcid}[1] != "1";

			$filenamexml = "$now_string"."_$chan{$rfcid}[2].xml";
			$filenamexmltvm = "$filenamexml.tvm";
			$filenamexmlgz = "$filenamexml.gz";

			if (! -e "$downloadprefix$filenamexml") {
			print "tvmovie: downloading files $baseurl$filenamexmltvm\n";
			my $dummy=GetContent("$baseurl$filenamexmltvm","$downloadprefix$filenamexmltvm");
			unscramble ("$downloadprefix$filenamexmltvm","$downloadprefix$filenamexmlgz");
			system("gunzip", "-f", "$downloadprefix$filenamexmlgz") == 0
				or warn "gunzip failed";
			}
		}
	}
}

################################################################################
# Get update xml-files from tvmovie online
################################################################################
sub GetUpdateFiles {
	$now_string = UnixDate("heute", "%Y%m%d");
	foreach $rfcid (keys %chan) {
		doexit() if $please_exit;

		# Kanal fr tvmovie konfiguriert ?
		next if $chan{$rfcid}[1] != "1";

		$filenamexml = "$now_string"."_$chan{$rfcid}[2].xml";
		$filenamexmltvm = "$filenamexml.tvm";
		$filenamexmlgz = "$filenamexml.gz";

		# Updatefiles werden IMMER neu geladen
		unlink "$updateprefix$filenamexmltvm"; unlink "$updateprefix$filenamexmlgz"; unlink "$updateprefix$filenamexml";

		if (! -e "$updateprefix$filenamexml") {
			print "tvmovie: downloading update files $aendurl$filenamexmltvm\n";
			my $dummy=GetContent("$aendurl$filenamexmltvm","$updateprefix$filenamexmltvm");
			unscramble ("$updateprefix$filenamexmltvm","$updateprefix$filenamexmlgz");
			system("gunzip", "-f", "$updateprefix$filenamexmlgz") == 0
				or warn "gunzip failed";
		}
	}
}

sub unscramble
{
    #Position .gz, Positon .tvm, Lnge
    #0x0000, 0x006A, 6
    #0x0006, 0x0064, 6
    #0x000C, 0x0070, 88
    #0x0064, 0x0320, 17
    #0x0075, 0x0011, 83
    #0x00C8, 0x012C, 100
    #0x012C, 0x0000, 17
    #0x013D, 0x0331, 183
    #0x01F4, 0x0258, 200
    #0x02BC, 0x0190, 200
    #0x0384, 0x00C8, 100
    #0x03E8, 0x03E8, Rest
    my $oldfilename = shift;
    my $filename = shift;
    print "tvmovie: descrambling $oldfilename to $filename\n";
    $size = -s $oldfilename;
	if ($size <= 1000) {
        rename $oldfilename, $filename;
        return;
    }

	open(OUT, "> $filename") || die "cannot write $filename: $!";
    open(IN,  "< $oldfilename") || warn "cannot read $oldfilename: $!";
    $outstring = "";
    seek (IN,0x006a,0) && read (IN,$outstring,  6) && print OUT $outstring;
    seek (IN,0x0064,0) && read (IN,$outstring,  6) && print OUT $outstring;
    seek (IN,0x0070,0) && read (IN,$outstring, 88) && print OUT $outstring;
    seek (IN,0x0320,0) && read (IN,$outstring, 17) && print OUT $outstring;
    seek (IN,0x0011,0) && read (IN,$outstring, 83) && print OUT $outstring;
    seek (IN,0x012c,0) && read (IN,$outstring,100) && print OUT $outstring;
    seek (IN,0x0000,0) && read (IN,$outstring, 17) && print OUT $outstring;
    seek (IN,0x0331,0) && read (IN,$outstring,183) && print OUT $outstring;
    seek (IN,0x0258,0) && read (IN,$outstring,200) && print OUT $outstring;
    seek (IN,0x0190,0) && read (IN,$outstring,200) && print OUT $outstring;
    seek (IN,0x00c8,0) && read (IN,$outstring,100) && print OUT $outstring;
    seek (IN,0x03e8,0) && read (IN,$outstring,10240000) && print OUT $outstring;
    close IN;
    close OUT;
    return;
exit;
}


# Process info from XMLTV file / channels.conf 
sub ReadExternalEPG_tvmovie
{
	GetFiles();
	GetUpdateFiles() unless ($useupdate == 0);

	foreach $sender (keys(%chan)) {
		# Kanal fr tvmovie konfiguriert ?
		next if $chan{$sender}[1] != "1";
		doexit() if $please_exit;

		$id=1;
		$firstchannel=1;
		$found_orig_event=0;
		$orig_epg_id=0;
		$laststreamid = 0;
		my (@events);
		# Find XML events
		$state="";

		my ($state,$event_id,$title,$subtitle,$datum,$zeit,$dauer,$text,$kritik) = "";
		for ($days=0;$days < $days2download ;$days++) {
			doexit() if $please_exit;

			$now_string = DateCalc("heute","+ $days tage",\$err,0);
			$now_string = UnixDate($now_string, "%Y%m%d");
			$xmlfile = "$downloadprefix$now_string"."_"."$chan{$sender}[2].xml";
			print "tvmovie: reading $downloadprefix$now_string"."_"."$chan{$sender}[2].xml int memory\n";
			open(XMLFILE, "$xmlfile") || warn "cannot open $xmlfile: $!";
			while(<XMLFILE>) {
				chomp;

	  			#$_ =~ s/\&amp\;/\&/g;
				$_ = decode_entities($_);
				$_ =~ s/\&bull\;/\*/g;
				$_ =~ s/\&amp;bull;/\*/g;
				if ( m|\<Sendung\>|) {
					$state = "a";
					$event_id=$title=$subtitle=$datum=$zeit=$dauer= "";
					$genre=$land=$jahr=$fsk=$keywords=$text=$kritik= "";
					$summary="";
					next;
				}
				$event_id = $1				if $state eq "a" && m|<SendungID>(.*?)</SendungID>|;
				$title = $1					if $state eq "a" && m|<Titel>(.*?)</Titel>|;
				$subtitle = $1				if $state eq "a" && m|<UnterTitel>(.*?)</UnterTitel>|;
				$datum = $1					if $state eq "a" && m|<Datum>(.*?)</Datum>|;	# 2003-10-30
				$zeit = $1					if $state eq "a" && m|<Zeit>(.*?)</Zeit>|;		# 20:15:00
				$dauer = $1	* 60			if $state eq "a" && m|<Dauer>(.*?)</Dauer>|;
				$genre = $1					if $state eq "a" && m|<GenreText>(.*?)</GenreText>|;
#				$genre = $1					if $state eq "a" && m|<RZPKategorieID>(.*?)</RZPKategorieID>|;
				$land = $1					if $state eq "a" && m|<Land>(.*?)</Land>|;
				$jahr = $1					if $state eq "a" && m|<Jahr>(.*?)</Jahr>|;
				$fsk = $1					if $state eq "a" && m|<FSK>(.*?)</FSK>|;
				$state = "e"				if $state eq "a" && m|</Sendung>|;

				# Beschreibung
				$state = "t"				if $state eq "a" && m|<Text Kategorie="Inhalt">|;
				$text .= $1 . "|"			if $state eq "t" && m|<Text>(.*?)</Text>|;
				$state = "a"				if $state eq "t" && m|^\s*</Text>|;

				# Kurzkritik
				$state = "kk"				if $state eq "a"  && m|<Text Kategorie="Kurzkritik">|;
				$kritik = "Kurzkritik: $1"	if $state eq "kk" && m|<Text>(.*?)</Text>|;
				$state = "a"				if $state eq "kk" && m|^\s*</Text>|;

				if ($state eq "e") { # Ende einer Sendung erreicht
					doexit() if $please_exit;

					$start = UnixDate("$datum $zeit", "%s");
					next if (UnixDate("heute", "%s") > $start+$dauer); # ist die Sendung schon vorbei ?
					$text =~ s/^(.*)\|$/$1/sig;
					
					#$kritik = $1 if kritik =~ m|^\s*(.*?)\s*$|;
					#$text = $1 if text =~ m|^\s*(.*?)\s*$|;

					$summary = "Genre: $genre|";
					$summary = "$land, $jahr, FSK: $fsk|" if $jahr != 0 && $fsk != 0;
					$summary .= "$kritik|" if $kritik ne "";
					$summary .= "$text" if $text ne "";

                    push(@events, {
						start        => $start, 
						stop         => $start + $dauer, 
						duration     => $dauer,
						title        => $title, 
						subtitle     => $subtitle, 
						summary      => $summary, 
						id           => $id,    
						event_id     => $event_id,
						state        => 1 # normale Sendung
					});
					$id++;
					$state = "";
					next;
				} # if ($state eq "e")
			} # while(<XMLFILE>) {
			close (XMLFILE);
		} # for ($days=0;$days < $days2download ;$days++) {

		# EPG-Daten sortieren
		my($last) = 0;
		my(@temp);
		for(sort({ $a->{start} <=> $b->{start} } @events)) {
			doexit() if $please_exit;
			next if($last == $_->{start});
			push(@temp, $_); 
			$last = $_->{start};
		}
		$XML{$sender} = [ @temp ];

		next unless ($useupdate == 1);
		# XML enthlt jetzt alle Daten des Senders. jetzt Updatefiles parsen und Eintrge aktualisieren
		# Okay, nicht schick. Dies gehrt in eine Prozedur, weils 2x aufgerufen wird ....
		$now_string = UnixDate("heute", "%Y%m%d");
		$xmlfile = "$updateprefix$now_string"."_"."$chan{$sender}[2].xml";
		print "tvmovie: reading $updateprefix$now_string"."_"."$chan{$sender}[2].xml int memory\n";
		open(XMLFILE, "$xmlfile") || warn "cannot open $xmlfile: $!";
		while(<XMLFILE>) {
			doexit() if $please_exit;

			chomp;
			$_ =~ s/\&amp\;/\&/g;
			$_ = decode_entities($_);
			$_ =~ s/\&bull\;/\*/g;
			if ( m|\<Sendung\>|) {
				$state = "a";
				$event_id=$title=$subtitle=$datum=$zeit=$dauer= "";
				$genre=$land=$jahr=$fsk=$keywords=$text=$textt=$kritik= "";
				$summary="";
				next;
			}
			$event_id = $1				if $state eq "a" && m|<SendungID>(.*?)</SendungID>|;
			$title = $1					if $state eq "a" && m|<Titel>(.*?)</Titel>|;
			$subtitle = $1				if $state eq "a" && m|<UnterTitel>(.*?)</UnterTitel>|;
			$datum = $1					if $state eq "a" && m|<Datum>(.*?)</Datum>|;	# 2003-10-30
			$zeit = $1					if $state eq "a" && m|<Zeit>(.*?)</Zeit>|;		# 20:15:00
			$dauer = $1	* 60			if $state eq "a" && m|<Dauer>(.*?)</Dauer>|;
			$genre = $1					if $state eq "a" && m|<GenreText>(.*?)</GenreText>|;
#			$genre = $1					if $state eq "a" && m|<RZPKategorieID>(.*?)</RZPKategorieID>|;
			$land = $1					if $state eq "a" && m|<Land>(.*?)</Land>|;
			$jahr = $1					if $state eq "a" && m|<Jahr>(.*?)</Jahr>|;
			$fsk = $1					if $state eq "a" && m|<FSK>(.*?)</FSK>|;
			$state = "e"				if $state eq "a" && m|</Sendung>|;

			# Beschreibung
			$state = "t"				if $state eq "a" && m|<Text Kategorie="Inhalt">|;
			$text .= $1 . "|"			if $state eq "t" && m|<Text>(.*?)</Text>|;
			$state = "a"				if $state eq "t" && m|^\s*</Text>|;

			# Thema (bei Dokus)
			$state = "th"				if $state eq "a" && m|<Text Kategorie="Thema">|;
			$textt .= $1 . "|"			if $state eq "th" && m|<Text>(.*?)</Text>|;
			$state = "a"				if $state eq "th" && m|^\s*</Text>|;

			# Kurzkritik
			$state = "kk"				if $state eq "a"  && m|<Text Kategorie="Kurzkritik">|;
			$kritik = "Kurzkritik: $1"	if $state eq "kk" && m|<Text>(.*?)</Text>|;
			$state = "a"				if $state eq "kk" && m|^\s*</Text>|;

			if ($state eq "e") { # Ende einer Sendung erreicht
				$start = UnixDate("$datum $zeit", "%s");
				next if (UnixDate("heute", "%s") > $start+$dauer); # ist die Sendung schon vorbei ?
				$text =~ s/^(.*)\|$/$1/sig;
				$textt =~ s/^(.*)\|$/$1/sig;
				
				#$kritik = $1 if kritik =~ m|^\s*(.*?)\s*$|;
				#$text = $1 if text =~ m|^\s*(.*?)\s*$|;

				$summary = "";
				$summary = "$land, $jahr, FSK: $fsk|" if $jahr != 0 && $fsk != 0;
				$summary .= "$kritik|" if $kritik ne "";
				$summary .= "Thema: $textt|" if $textt ne "";
				$summary .= "$text" if $text ne "";

				for ($i=0; $i<$#{$XML{$sender}};$i++) {
					if (@{$XML{$sender}}[$i]->{event_id} eq $event_id) {
						print "updating $title\n";
						@{$XML{$sender}}[$i]->{start}        = $start;
						@{$XML{$sender}}[$i]->{stop}         = $start + $dauer;
						@{$XML{$sender}}[$i]->{duration}     = $dauer;
						@{$XML{$sender}}[$i]->{title}        = $title; 
						@{$XML{$sender}}[$i]->{subtitle}     = $subtitle;
						@{$XML{$sender}}[$i]->{summary}      = $summary; 
						@{$XML{$sender}}[$i]->{state}        = 2; # aktualisierte Sendung

						# Updatesendung, die als Livesendung andere Sendungen ausblendet?
						for ($j=0; $j<$#{$XML{$sender}};$j++) {
							if (@{$XML{$sender}}[$j]->{state} eq 0 && 
								@{$XML{$sender}}[$j]->{start} >= $start &&
								@{$XML{$sender}}[$j]->{stop} < $start + $dauer) {
									@{$XML{$sender}}[$j]->{state}        = 0; # gelschte Sendung

							}
						}
					}
				}

				$id++;
				$state = "";
				next;
			} # if ($state eq "e")
		} # while(<XMLFILE>) {
		close (XMLFILE);
		# XML enthlt jetzt auch die nderungen
	} # foreach $sender (keys(%chan))
} # sub ProcessEpg

return 1;
